=======================
General Troubleshooting
=======================

Diagnosing typical errors
-------------------------
It is common to run into errors as 


Getting Help
------------
The RIFT developers are ... Further help can be sought via (email list/chat channels)
